init abstract method
Initialize the platform implementation so that subsequent calls can be made synchronously
Implementation
Future<void> init();
Initialize the platform implementation so that subsequent calls can be made synchronously
Future<void> init();